==> estateplat-common-1.2.4-20210325.092708-678-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxFsss.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;


/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0
 * @description 外网申请附属设施信息表
 */
@Table(name = "GX_WW_SQXX_FSSS")
public class GxWwSqxxFsss {
    @Id
    private String fsssid;
    private String bdcdyh;
    private String bdcdybh;
    private String bdcqzh;
    private String xmid;
    private String htbh;
    private Date basj;
    private String fkfsdm;
    private String fkfsmc;
    private Double jyjg;
    private String htzl;

    public String getFsssid() {
        return fsssid;
    }

    public void setFsssid(String fsssid) {
        this.fsssid = fsssid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public String getFkfsdm() {
        return fkfsdm;
    }

    public void setFkfsdm(String fkfsdm) {
        this.fkfsdm = fkfsdm;
    }

    public String getFkfsmc() {
        return fkfsmc;
    }

    public void setFkfsmc(String fkfsmc) {
        this.fkfsmc = fkfsmc;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getHtzl() {
        return htzl;
    }

    public void setHtzl(String htzl) {
        this.htzl = htzl;
    }
}

==> estateplat-common-1.2.4-20210326.012715-681-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxFsss.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;


/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0
 * @description 外网申请附属设施信息表
 */
@Table(name = "GX_WW_SQXX_FSSS")
public class GxWwSqxxFsss {
    @Id
    private String fsssid;
    private String bdcdyh;
    private String bdcdybh;
    private String bdcqzh;
    private String xmid;
    private String htbh;
    private Date basj;
    private String fkfsdm;
    private String fkfsmc;
    private Double jyjg;
    private String htzl;
    private String sqxxid;

    public String getFsssid() {
        return fsssid;
    }

    public void setFsssid(String fsssid) {
        this.fsssid = fsssid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public String getFkfsdm() {
        return fkfsdm;
    }

    public void setFkfsdm(String fkfsdm) {
        this.fkfsdm = fkfsdm;
    }

    public String getFkfsmc() {
        return fkfsmc;
    }

    public void setFkfsmc(String fkfsmc) {
        this.fkfsmc = fkfsmc;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getHtzl() {
        return htzl;
    }

    public void setHtzl(String htzl) {
        this.htzl = htzl;
    }

    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }
}
